@@ -1,9 +1,9 @@
-__all__ = ['acroread',
-           'Banshee',
+__all__ = ['Banshee',
            'ddu',
            'Eclipse',
            'ekiga',
            'empathy',
+           'evince',
            'evolution',
            'gajim',
            'gcalctool',
